========
Resolwe
========
.. automodule:: orangecontrib.bioinformatics.resolwe
.. autofunction:: orangecontrib.bioinformatics.resolwe.connect

.. autoclass:: orangecontrib.bioinformatics.resolwe.GenAPI
   :members:
   :special-members: __init__


